==> tdeutils-14.0.9-x86_64-ifx.txz: install/doinst.sh <==

# Update the desktop database:
/usr/bin/update-desktop-database ./usr/share/applications

# Update hicolor theme cache:
/usr/bin/gtk-update-icon-cache -f -t ./usr/share/icons/hicolor

# Update the mime database:
/usr/bin/update-mime-database -Vn usr/share/mime

( cd usr/lib64 ; rm -rf libkcmlaptop.so )
( cd usr/lib64 ; ln -sf libkcmlaptop.so.0 libkcmlaptop.so )
( cd usr/lib64 ; rm -rf libkcmlaptop.so.0 )
( cd usr/lib64 ; ln -sf libkcmlaptop.so.0.0.0 libkcmlaptop.so.0 )
( cd usr/lib64 ; rm -rf libkhexeditcommon.so )
( cd usr/lib64 ; ln -sf libkhexeditcommon.so.0 libkhexeditcommon.so )
( cd usr/lib64 ; rm -rf libkhexeditcommon.so.0 )
( cd usr/lib64 ; ln -sf libkhexeditcommon.so.0.0.0 libkhexeditcommon.so.0 )
( cd usr/lib64 ; rm -rf libkmilo.so )
( cd usr/lib64 ; ln -sf libkmilo.so.1 libkmilo.so )
( cd usr/lib64 ; rm -rf libkmilo.so.1 )
( cd usr/lib64 ; ln -sf libkmilo.so.1.0.0 libkmilo.so.1 )
( cd usr/lib64 ; rm -rf libkregexpeditorcommon.so )
( cd usr/lib64 ; ln -sf libkregexpeditorcommon.so.1 libkregexpeditorcommon.so )
( cd usr/lib64 ; rm -rf libkregexpeditorcommon.so.1 )
( cd usr/lib64 ; ln -sf libkregexpeditorcommon.so.1.0.0 libkregexpeditorcommon.so.1 )
( cd usr/lib64 ; rm -rf libksimcore.so )
( cd usr/lib64 ; ln -sf libksimcore.so.1 libksimcore.so )
( cd usr/lib64 ; rm -rf libksimcore.so.1 )
( cd usr/lib64 ; ln -sf libksimcore.so.1.0.0 libksimcore.so.1 )
( cd usr/share/doc/tde/HTML/en/KRegExpEditor ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/KRegExpEditor ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/ark ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/ark ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/irkick ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/irkick ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcalc ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcalc ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcharselect ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcharselect ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcmlirc ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcmlirc ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kcmlowbatcrit ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kcmlowbatwarn ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kvaio ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kvaio ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/laptop ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/laptop ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/powerctrl ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/powerctrl ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/storagedevices ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/storagedevices ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/thinkpad ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/thinkpad ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kdf ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kdf ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kedit ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kedit ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kfloppy ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kfloppy ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kgpg ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kgpg ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/khexedit ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/khexedit ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kjots ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kjots ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/ksim ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/ksim ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/ktimer ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/ktimer ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/superkaramba ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/superkaramba ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/tdewallet ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/tdewallet ; ln -sf /usr/share/doc/tde/HTML/en/common common )

==> tdeutils-14.0.11-x86_64-ifx.txz: install/doinst.sh <==

# Update the desktop database:
/usr/bin/update-desktop-database ./usr/share/applications

# Update hicolor theme cache:
/usr/bin/gtk-update-icon-cache -f -t ./usr/share/icons/hicolor

# Update the mime database:
/usr/bin/update-mime-database -Vn usr/share/mime

( cd usr/lib64 ; rm -rf libkcmlaptop.so )
( cd usr/lib64 ; ln -sf libkcmlaptop.so.0 libkcmlaptop.so )
( cd usr/lib64 ; rm -rf libkcmlaptop.so.0 )
( cd usr/lib64 ; ln -sf libkcmlaptop.so.0.0.0 libkcmlaptop.so.0 )
( cd usr/lib64 ; rm -rf libkhexeditcommon.so )
( cd usr/lib64 ; ln -sf libkhexeditcommon.so.0 libkhexeditcommon.so )
( cd usr/lib64 ; rm -rf libkhexeditcommon.so.0 )
( cd usr/lib64 ; ln -sf libkhexeditcommon.so.0.0.0 libkhexeditcommon.so.0 )
( cd usr/lib64 ; rm -rf libkmilo.so )
( cd usr/lib64 ; ln -sf libkmilo.so.1 libkmilo.so )
( cd usr/lib64 ; rm -rf libkmilo.so.1 )
( cd usr/lib64 ; ln -sf libkmilo.so.1.0.0 libkmilo.so.1 )
( cd usr/lib64 ; rm -rf libkregexpeditorcommon.so )
( cd usr/lib64 ; ln -sf libkregexpeditorcommon.so.1 libkregexpeditorcommon.so )
( cd usr/lib64 ; rm -rf libkregexpeditorcommon.so.1 )
( cd usr/lib64 ; ln -sf libkregexpeditorcommon.so.1.0.0 libkregexpeditorcommon.so.1 )
( cd usr/lib64 ; rm -rf libksimcore.so )
( cd usr/lib64 ; ln -sf libksimcore.so.1 libksimcore.so )
( cd usr/lib64 ; rm -rf libksimcore.so.1 )
( cd usr/lib64 ; ln -sf libksimcore.so.1.0.0 libksimcore.so.1 )
( cd usr/share/doc/tde/HTML/en/KRegExpEditor ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/KRegExpEditor ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/ark ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/ark ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/irkick ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/irkick ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcalc ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcalc ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcharselect ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcharselect ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kcmlirc ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kcmlirc ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kcmlowbatcrit ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kcmlowbatwarn ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kvaio ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/kvaio ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/laptop ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/laptop ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/powerctrl ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/powerctrl ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/storagedevices ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/storagedevices ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/thinkpad ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/thinkpad ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kdf ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kdf ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kedit ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kedit ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kfloppy ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kfloppy ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kgpg ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kgpg ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/khexedit ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/khexedit ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kjots ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kjots ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/ksim ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/ksim ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/ktimer ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/ktimer ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/superkaramba ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/superkaramba ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/tdewallet ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/tdewallet ; ln -sf /usr/share/doc/tde/HTML/en/common common )
